OpenToolClient class

Inheritance

Constructors

OpenToolClient({bool? isSSL, required String toolHost, required int toolPort, String? toolApiKey})

Properties

dio ↔ Dio
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
host String
getter/setter pair
isSSL bool
getter/setter pair
port int
getter/setter pair
prefix String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolApiKey String?
getter/setter pair

Methods

call(FunctionCall functionCall) Future<ToolReturn>
override
load() Future<OpenTool?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stop() Future<StatusInfo?>
override
streamCall(FunctionCall functionCall, void onStream(String event, ToolReturn toolReturn)) Future<void>
override
toString() String
A string representation of this object.
inherited
version() Future<Version>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited