CliArguments class

Constructors

CliArguments(List<String> args)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCustomMultiOption(String name, {String? abbr, String? help, String? valueHelp, Iterable<String>? allowed, Map<String, String>? allowedHelp, Iterable<String>? defaultsTo, void callback(List<String>)?, bool splitCommas = true, bool hide = false, List<String> aliases = const []}) CliArguments
addCustomOption(String name, {String? abbr, String? help, String? valueHelp, Iterable<String>? allowed, Map<String, String>? allowedHelp, String? defaultsTo, void callback(String?)?, bool mandatory = false, bool hide = false, List<String> aliases = const []}) CliArguments
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited