CliTool class abstract

Inheritance

Constructors

CliTool()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String name, Map<String, dynamic>? arguments) Future<Map<String, dynamic>>
inherited
dispose() Future<void>
inherited
init() Future<void>
inherited
initArgs(Map<String, dynamic>? args) Future<Map<String, dynamic>?>
load() Future<OpenTool?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
streamCall(String name, Map<String, dynamic>? arguments, void onEvent(String event, Map<String, dynamic> data)) Future<void>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited