OpenTool class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Constructors
-
OpenTool({required String opentool, required Info info, ServerConfig? server, required List<
FunctionModel> functions, Map<String, Schema> ? schemas}) -
OpenTool.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
functions
↔ List<
FunctionModel> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- info ↔ Info
-
getter/setter pair
- opentool ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schemas
↔ Map<
String, Schema> ? -
getter/setter pair
- server ↔ ServerConfig?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited