OpenToolJsonLoader class

Constructors

OpenToolJsonLoader()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemasJson Map<String, dynamic>?
getter/setter pair

Methods

load(String jsonString) Future<OpenTool>
loadFromFile(String jsonPath) Future<OpenTool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited