ToolBreakException class

When client catch ToolBreakException. The client should be stopped calling.

Implemented types
Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false, createFactory: false)

Constructors

ToolBreakException(String? message)

Properties

code int
final
hashCode int
The hash code for this object.
no setterinherited
message String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited