Tool class abstract
- Implementers
Constructors
- Tool()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
String name, Map< String, dynamic> ? arguments) → Future<Map< String, dynamic> > -
dispose(
) → Future< void> -
init(
) → Future< void> -
load(
) → Future< OpenTool?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
streamCall(
String name, Map< String, dynamic> ? arguments, void onEvent(String event, Map<String, dynamic> data)) → Future<void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited